@@ -18,11 +18,6 @@ class MySQLMetadataStore(BaseMetadataStore):
     # Class Configuration
     FLAVOR: ClassVar[str] = "mysql"
 
-    @property
-    def upgrade_migration_enabled(self) -> bool:
-        """Return True to enable automatic database schema migration."""
-        return True
-
     def get_tfx_metadata_config(
         self,
     ) -> Union[
